==> aliyun-python-sdk-cloudapi-1.0.2.tar.gz: aliyun-python-sdk-cloudapi-1.0.2/aliyunsdkcloudapi/request/v20160714/RemoveIpControlPolicyItemRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudapi.endpoint import endpoint_data

class RemoveIpControlPolicyItemRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'RemoveIpControlPolicyItem','apigateway')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_PolicyItemIds(self): # String
		return self.get_query_params().get('PolicyItemIds')

	def set_PolicyItemIds(self, PolicyItemIds):  # String
		self.add_query_param('PolicyItemIds', PolicyItemIds)
	def get_IpControlId(self): # String
		return self.get_query_params().get('IpControlId')

	def set_IpControlId(self, IpControlId):  # String
		self.add_query_param('IpControlId', IpControlId)
	def get_SecurityToken(self): # String
		return self.get_query_params().get('SecurityToken')

	def set_SecurityToken(self, SecurityToken):  # String
		self.add_query_param('SecurityToken', SecurityToken)

==> aliyun-python-sdk-cloudapi-3.8.2.tar.gz: aliyun-python-sdk-cloudapi-3.8.2/aliyunsdkcloudapi/request/v20160714/RemoveIpControlPolicyItemRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class RemoveIpControlPolicyItemRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'RemoveIpControlPolicyItem')

	def get_IpControlId(self):
		return self.get_query_params().get('IpControlId')

	def set_IpControlId(self,IpControlId):
		self.add_query_param('IpControlId',IpControlId)

	def get_SecurityToken(self):
		return self.get_query_params().get('SecurityToken')

	def set_SecurityToken(self,SecurityToken):
		self.add_query_param('SecurityToken',SecurityToken)

	def get_PolicyItemIds(self):
		return self.get_query_params().get('PolicyItemIds')

	def set_PolicyItemIds(self,PolicyItemIds):
		self.add_query_param('PolicyItemIds',PolicyItemIds)
